cachel
======

.. image:: https://travis-ci.org/baverman/cachel.svg?branch=master
   :target: https://travis-ci.org/baverman/cachel

.. image:: https://img.shields.io/badge/coverage-100%25-brightgreen.svg

.. image:: https://img.shields.io/badge/python-2.7%2C_3.4%2C_3.5%2C_pypy-blue.svg

Fast caches for python
